@@ -1,6 +1,6 @@
 /*
  *	cook - a program construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1997 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * MANIFEST: functions to provide common -VERSion behaviour
  */
 
-#include <stdio.h>
+#include <ac/stdio.h>
 
 #include <arglex.h>
 #include <error.h>
