@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1997-1999, 2001, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -62,8 +62,10 @@ static table_ty table[] =
 	{ "no-errok",		RF_ERROK_OFF,	RF_ERROK,		},
 	{ "noerrok",		RF_ERROK_OFF,	RF_ERROK,		},
 	{ "fingerprint",	RF_FINGERPRINT,	RF_FINGERPRINT_OFF,	},
+	{ "fingerprints",	RF_FINGERPRINT,	RF_FINGERPRINT_OFF,	},
 	{ "fingerprinting",	RF_FINGERPRINT,	RF_FINGERPRINT_OFF,	},
 	{ "no-fingerprint",	RF_FINGERPRINT_OFF, RF_FINGERPRINT,	},
+	{ "no-fingerprints",	RF_FINGERPRINT_OFF, RF_FINGERPRINT,	},
 	{ "nofingerprint",	RF_FINGERPRINT_OFF, RF_FINGERPRINT,	},
 	{ "no-fingerprinting",	RF_FINGERPRINT_OFF, RF_FINGERPRINT,	},
 	{ "nofingerprinting",	RF_FINGERPRINT_OFF, RF_FINGERPRINT,	},
