@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1994-1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@
 #include <ac/string.h>
 #include <ac/stdio.h>
 #include <ac/stdlib.h>
-#include <signal.h>
+#include <ac/signal.h>
 
 #include <arglex.h>
 #include <builtin.h>
