@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1997-1999, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -134,7 +134,7 @@ execute(op, icp)
 		(
 			&this->pos,
 			0,
-			i18n("attempt to instanciate recipe with no targets")
+			i18n("attempt to instantiate recipe with no targets")
 		);
 		status = opcode_status_error;
 		goto done;
@@ -208,7 +208,7 @@ execute(op, icp)
 			(
 				&this->pos,
 				0,
-				i18n("implicit recipe instanciated (reason)")
+				i18n("implicit recipe instantiated (reason)")
 			);
 		}
 		else
@@ -217,7 +217,7 @@ execute(op, icp)
 			(
 				&this->pos,
 				0,
-				i18n("explicit recipe instanciated (reason)")
+				i18n("explicit recipe instantiated (reason)")
 			);
 		}
 	}
